==> fengoffice-1.7.5.tbz: www/fengoffice/language/ja_jp/objects.php <==
<?php

  return array(

    // Objects
    'user' => 'ユーザー',
    'group' => 'グループ',
    'groups' => 'グループ',
    'users' => 'ユーザー',
    'member' => 'メンバー',
    'members' => 'メンバー',
    'company' => '会社',
    'companies' => '会社',
    'client' => '顧客',
    'clients' => '顧客',
    'package' => 'パッケージ',
    'project' => 'ワークスペース',
    'projects' => 'ワークスペース',
    'message' => 'ノート',
    'messages' => 'ノート',
    'comment' => 'コメント',
    'comments' => 'コメント',
    'milestone' => 'マイルストーン',
    'milestones' => 'マイルストーン',
    'task' => 'タスク',
    'subtasks' => 'サブタスク',
    'tasks' => 'タスク',
    'task list' => 'タスク',
    'task lists' => 'タスク',
    'tag' => 'タグ',
    'tags' => 'タグ',
    'attachment' => '添付ファイル',
    'attachments' => '添付ファイル',
    'object subscribers' => '登録者',
    'form' => 'フォーム',
    'forms' => 'フォーム',
    'file' => 'ファイル',
    'files' => 'ファイル',
    'file revision' => 'ファイルのリビジョン',
    'file revisions' => 'ファイルのリビジョン',
    'file contents' => 'ファイルの内容',
    'revision' => 'リビジョン',
    'revisions' => 'リビジョン',
    'folder' => 'フォルダー',
    'folders' => 'フォルダー',
    'configuration category' => '構成のカテゴリ',
    'configuration categories' => '構成のカテゴリ',
    'handin' => 'ハンドイン',
    'handins' => 'ハンドイン',
    'emailunclassified' => 'メール',

    'load file' => 'ファイルを読み込み',
    'time' => '時間',
    'reporting' => 'レポート',

    // Variations
    'modify object subscribers' => '登録者を変更',
    'subscription modified successfully' => '登録者を変更しました。',
    'owner company' => 'オーナ会社',
    'client companies' => '顧客企業',

    'open milestone' => '未完のマイルストーン',
    'open milestones' => '未完のマイルストーン',
    'completed milestone' => '完了したマイルストーン',
    'completed milestones' => '完了したマイルストーン',
    'late milestones' => '遅れているマイルストーン',
    'late milestones and tasks' => '遅れているマイルストーンとタスク',
    'today milestones' => '今日のマイルストーン',
    'upcoming milestones' => '次回のマイルストーン',
    'completed task list' => '完了したタスク',
    'completed task lists' => '完了したタスク',
    'open task list' => '未完のタスク',
    'open task lists' => '未完のタスク',
    'active project' => '活動状態にあるワークスペース',
    'active projects' => '活動状態にあるワークスペース',
    'finished project' => '終了状態のワークスペース',
    'finished projects' => '終了状態のワークスペース',
    'linked object' => 'リンクされたオブジェクト',
    'linked objects' => 'リンクされたオブジェクト',

    'important message' => '重要なノート',
    'important messages' => '重要なノート',
    'important file' => '重要なファイル',
    'important files' => '重要なファイル',
    'parent task' => '親のタスク',

    'private message' => '親のノート',
    'private milestone' => 'プライベートなマイルストーン',
    'private task list' => 'プライベートなタスク',
    'private comment' => 'プライベートなコメント',
    'private file' => 'プライベートなファイル',

    'urgent milestone' => '緊急',

    'object reminders' => 'リマインダー',
    'add object reminder' => 'リマインダーを追加',

    'create document' => 'ドキュメントを作成',
    'create presentation' => 'プレゼンテーションを作成',
  
    'the message' => 'ノート',
    'the email' => 'メール',
    'the emailunclassified' => 'メール',
    'the contact' => '連絡先',
    'the company' => '会社',
    'the event' => 'イベント',
    'the file' => 'ファイル',
    'the file revision' => 'ファイルのリビジョン',
    'the task' => 'タスク',
    'the milestone' => 'マイルストーン',
    'the webpage' => 'ウェブリンク',
    'the comment' => 'コメント',
    'the user' => 'ユーザー',
    'the project' => 'ワークスペース',
    'the file_revision' => 'ファイルのリビジョン',

    'activity add' => "{1}が{0} {2}を追加",
    'activity edit' => "{1}が{0} {2}を編集",
    'activity delete' => "{1}が{0} {2}を削除",
    'activity trash' => "{1}が{0} {2}をごみ箱に移動",
    'activity untrash' => "{1}が{0} {2}をごみ箱から復元",
    'activity open' => "{1}が{0} {2}を未完了に設定",
    'activity close' => "{1}が{0} {2}を完了に設定",
    'activity subscribe' => "{1}が{0} {2}に{3}を登録",
    'activity unsubscribe' => "{1}が{0} {2}から{3}の登録を解除",
    'activity tag' => "{1}が{0} {2}にタグ{3}を追加",
    'activity untag' => "{1}が{0} {2}からタグを削除",
    'activity comment' => "{1}が{0} {2}にコメント: <br>&nbsp;&nbsp;&nbsp;&nbsp;\"{3}\"",
    'activity link' => "{1}が{0}{2}と{3}{4}をリンク",
    'activity unlink' => "{1}が{0}{2}と{3}{4}のリンクを解除",
    'activity login' => "{0}がログイン",
    'activity logout' => "{0}がログアウト",
    'activity archive' => "{1}さんが{0} {2}を書庫に収納",
    'activity unarchive' => "{1}さんが{0} {2}を書庫から取り出し",
    'activity move from to' => "{1}が{3}から{4}へ{0} {2}を移動",
    'activity move from' => "{1}が{3}から{0} {2}を移動",
    'activity move to' => "{1}が{2}に{0} {2}を移動",
    'activity move' => "{1}が{0} {2}を移動",
    'activity copy to' => "{1}が{3}へ{0} {2}をコピー",
    'activity copy' => "{1}が{0} {2}をコピー",
    'activity read' => "{1}が{0} {2}を既読",
    'activity download' => "{1}が{0} {2}をダウンロード",
    'activity checkout' => "{1}が{0} {2}をチェックアウト",
    'activity checkin' => "{1}が{0} {2}をチェックイン",

    'x users' => "{0} ユーザー{1}",
  ); // array

?>

==> fengoffice-2.0.0.tbz: www/fengoffice/language/ja_jp/objects.php <==
<?php

  return array(

    // Objects
    'user' => 'ユーザ',
    'group' => 'グループ',
    'groups' => 'グループ',
    'users' => 'ユーザ',
    'member' => 'メンバー',
    'members' => 'メンバー',
    'company' => '会社',
    'companies' => '会社',
    'client' => '顧客',
    'clients' => '顧客',
    'package' => 'パッケージ',
    'project' => 'ワークスペース',
    'projects' => 'ワークスペース',
    'message' => 'ノート',
    'messages' => 'ノート',
    'comment' => 'コメント',
    'comments' => 'コメント',
    'milestone' => 'マイルストーン',
    'milestones' => 'マイルストーン',
    'task' => 'タスク',
    'subtasks' => 'サブタスク',
    'tasks' => 'タスク',
    'task list' => 'タスク',
    'task lists' => 'タスク',
    'tag' => 'タグ',
    'tags' => 'タグ',
    'attachment' => '添付ファイル',
    'attachments' => '添付ファイル',
    'object subscribers' => '購読者',
    'form' => 'フォーム',
    'forms' => 'フォーム',
    'file' => 'ファイル',
    'files' => 'ファイル',
    'file revision' => 'ファイルのリビジョン',
    'file revisions' => 'ファイルのリビジョン',
    'file contents' => 'ファイルの内容',
    'revision' => 'リビジョン',
    'revisions' => 'リビジョン',
    'folder' => 'フォルダ',
    'folders' => 'フォルダ',
    'configuration category' => '環境設定のカテゴリ',
    'configuration categories' => '環境設定のカテゴリ',
    'handin' => 'ハンドイン',
    'handins' => 'ハンドイン',
    'emailunclassified' => 'メール',

    'load file' => 'ファイルを読み込み',
    'time' => '時刻',
    'reporting' => 'レポート',

    // Variations
    'modify object subscribers' => '購読者を変更',
    'subscription modified successfully' => '購読者の変更に成功しました。',
    'owner company' => 'オーナ会社',
    'client companies' => '顧客企業',

    'open milestone' => '未完のマイルストーン',
    'open milestones' => '未完のマイルストーン',
    'completed milestone' => '完了したマイルストーン',
    'completed milestones' => '完了したマイルストーン',
    'late milestones' => '遅れているマイルストーン',
    'late milestones and tasks' => '遅れているマイルストーンとタスク',
    'today milestones' => '今日のマイルストーン',
    'upcoming milestones' => '次回のマイルストーン',
    'completed task list' => '完了したタスク',
    'completed task lists' => '完了したタスク',
    'open task list' => '未完のタスク',
    'open task lists' => '未完のタスク',
    'active project' => '活動状態にあるワークスペース',
    'active projects' => '活動状態にあるワークスペース',
    'finished project' => '終了状態のワークスペース',
    'finished projects' => '終了状態のワークスペース',
    'linked object' => 'リンクされたオブジェクト',
    'linked objects' => 'リンクされたオブジェクト',

    'important message' => '重要なノート',
    'important messages' => '重要なノート',
    'important file' => '重要なファイル',
    'important files' => '重要なファイル',
    'parent task' => '親のタスク',

    'private message' => '親のノート',
    'private milestone' => 'プライベートなマイルストーン',
    'private task list' => 'プライベートなタスク',
    'private comment' => 'プライベートなコメント',
    'private file' => 'プライベートなファイル',

    'urgent milestone' => '緊急',

    'object reminders' => 'リマインダー',
    'add object reminder' => 'リマインダーを追加',

    'create document' => 'ドキュメントを作成',
    'create presentation' => 'プレゼンテーションを作成',
  
    'the message' => 'ノート',
    'the email' => 'メール',
    'the emailunclassified' => 'メール',
    'the contact' => '連絡先',
    'the company' => '会社',
    'the event' => 'イベント',
    'the file' => 'ファイル',
    'the file revision' => 'ファイルのリビジョン',
    'the task' => 'タスク',
    'the milestone' => 'マイルストーン',
    'the webpage' => 'ウェブリンク',
    'the comment' => 'コメント',
    'the user' => 'ユーザ',
    'the project' => 'ワークスペース',

    'activity add' => "{1}が{0} {2}を追加しました",
    'activity edit' => "{1}が{0} {2}を編集しました",
    'activity delete' => "{1}が{0} {2}を削除しました",
    'activity trash' => "{1}が{0} {2}をごみ箱に入れました",
    'activity untrash' => "{1}が{0} {2}をごみ箱から出しました",
    'activity open' => "{1}が{0} {2}を開きました",
    'activity close' => "{1}が{0} {2}を閉じました",
    'activity subscribe' => "{1}が{0} {2}に{3}を購読させました",
    'activity unsubscribe' => "{1}が{0} {2}から{3}の購読を解除させました",
    'activity tag' => "{1}が{0} {2}にタグ{3}をつけました",
    'activity untag' => "{1}が{0} {2}からタグを削除しました",
    'activity comment' => "{1}が{0} {2}にコメントしました: <br>&nbsp;&nbsp;&nbsp;&nbsp;\"{3}\"",
    'activity link' => "{1}が{3} {4}で{0} {2}をリンクしました",
    'activity unlink' => "{1}が{3} {4}から{0} {2}のリンクを解除しました",
    'activity login' => "{0}がログインしました",
    'activity logout' => "{0}がログアウトしました",
    'activity archive' => "{1}が{0} {2}をアーカイブしました",
    'activity unarchive' => "{1}が{0} {2}のアーカイブを解除しました",
    'activity move from to' => "{1}が{3}から{4}へ{0} {2}を移動しました",
    'activity move from' => "{1}が{3}から{0} {2}を移動しました",
    'activity move to' => "{1}が{2}に{0} {2}を移動しました",
    'activity move' => "{1}が{0} {2}を移動しました",
    'activity copy to' => "{1}が{3}へ{0} {2}をコピーしました",
    'activity copy' => "{1}が{0} {2}をコピーしました",
    'activity read' => "{1}が{0} {2}を読みました",
    'activity download' => "{1}が{0} {2}をダウンロードしました",

    'x users' => "{0} ユーザ{1}",
  ); // array

?>
